@@ -35,11 +35,15 @@ from instagrapi.mixins.share import ShareMixin
 from instagrapi.mixins.story import StoryMixin
 from instagrapi.mixins.timeline import ReelsMixin
 from instagrapi.mixins.totp import TOTPMixin
+from instagrapi.mixins.track import TrackMixin
 from instagrapi.mixins.user import UserMixin
 from instagrapi.mixins.video import DownloadVideoMixin, UploadVideoMixin
 
 requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
 
+# Used as fallback logger if another is not provided.
+DEFAULT_LOGGER = logging.getLogger("instagrapi")
+
 
 class Client(
     PublicRequestMixin,
@@ -49,6 +53,7 @@ class Client(
     ProfilePublicMixin,
     LoginMixin,
     ShareMixin,
+    TrackMixin,
     FbSearchMixin,
     HighlightMixin,
     DownloadPhotoMixin,
@@ -80,13 +85,22 @@ class Client(
     FundraiserMixin
 ):
     proxy = None
-    logger = logging.getLogger("instagrapi")
 
-    def __init__(self, settings: dict = {}, proxy: str = None, delay_range: list = None, **kwargs):
+    def __init__(self,
+                 settings: dict = {},
+                 proxy: str = None,
+                 delay_range: list = None,
+                 logger=DEFAULT_LOGGER,
+                 **kwargs):
+
         super().__init__(**kwargs)
+
         self.settings = settings
+        self.logger = logger
         self.delay_range = delay_range
+        
         self.set_proxy(proxy)
+
         self.init()
 
     def set_proxy(self, dsn: str):
